@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::VersionStorage::Standard::VersionResult;
-$DBIx::Class::DeploymentHandler::VersionStorage::Standard::VersionResult::VERSION = '0.002220';
+$DBIx::Class::DeploymentHandler::VersionStorage::Standard::VersionResult::VERSION = '0.002221';
 # ABSTRACT: The typical way to store versions in the database
 
 use strict;
@@ -7,7 +7,9 @@ use warnings;
 
 use parent 'DBIx::Class::Core';
 
-__PACKAGE__->table('dbix_class_deploymenthandler_versions');
+my $table = 'dbix_class_deploymenthandler_versions';
+
+__PACKAGE__->table($table);
 
 __PACKAGE__->add_columns (
   id => {
@@ -34,6 +36,17 @@ __PACKAGE__->set_primary_key('id');
 __PACKAGE__->add_unique_constraint(['version']);
 __PACKAGE__->resultset_class('DBIx::Class::DeploymentHandler::VersionStorage::Standard::VersionResultSet');
 
+sub sqlt_deploy_hook {
+  my ( $self, $sqlt_table ) = @_;
+  my $tname = $sqlt_table->name;
+  return if $tname eq $table;
+  # give indices unique names for sub-classes on different tables
+  foreach my $c ( $sqlt_table->get_constraints ) {
+    ( my $cname = $c->name ) =~ s/\Q$table\E/$tname/;
+    $c->name($cname);
+  }
+}
+
 1;
 
 # vim: ts=2 sw=2 expandtab
